#!/bin/bash
set -e

if [ -z "$TMPDIR" ]; then
    TMPDIR="/tmp"
fi
tmpdir=$(mktemp -d "$TMPDIR/snappy-debug-tests.XXXXXX")
trap 'rm -rf $tmpdir' EXIT HUP INT QUIT TERM


echo "Test with test.log"
if SNAP=. ./bin/snappy-security-scanlog -r --policy-version=16 --log-file=./test.log | tee "$tmpdir/test.log.output" ; then
    echo PASS
else
    echo FAIL
    exit 1
fi

echo ""
echo -n "Compare test.log output: "
if diff -Naur ./test.log.output "$tmpdir/test.log.output" ; then
    echo PASS
else
    echo FAIL
    exit 1
fi

# bad version
echo ""
echo -n "Test bad policy version: "
if SNAP=. ./bin/snappy-security-scanlog -r --policy-version=14 --log-file=./test.log >/dev/null 2>&1 ; then
    echo FAIL
    exit 1
else
    echo PASS
fi

echo ""
echo -n "Test filter with --only-snap=not-in-test --only-apparmor: "
out=$(SNAP=. ./bin/snappy-security-scanlog --only-apparmor --only-snap=not-in-test -r --policy-version=16 --log-file=./test.log | wc -l)
if [ "$out" = "0" ]; then
    echo PASS
else
    echo "Found $out entries"
    echo FAIL
    exit 1
fi

echo ""
echo -n "Test filter with --only-snap=test-only-snap --only-apparmor: "
out=$(SNAP=. ./bin/snappy-security-scanlog --only-apparmor --only-snap=test-only-snap -r --policy-version=16 --log-file=./test.log | grep -c '^Log: ')
if [ "$out" = "1" ]; then
    echo PASS
else
    echo "Found $out entries"
    echo FAIL
    exit 1
fi

echo ""
echo -n "Test filter with --only-snap=devmode-test --only-apparmor: "
out=$(SNAP=. ./bin/snappy-security-scanlog --only-apparmor --only-snap=devmode-test -r --policy-version=16 --log-file=./test.log | grep -c '^Log: ')
if [ "$out" = "1" ]; then
    echo PASS
else
    echo "Found $out entries"
    echo FAIL
    exit 1
fi

echo ""
echo -n "Test skipping restricted for seccomp: "
out=$(SNAP=. ./bin/snappy-security-scanlog --only-seccomp -r --policy-version=16 --log-file=./test.log | grep -c 'kernel-module-control')
if [ "$out" = "0" ]; then
    echo PASS
else
    echo "Found $out entries"
    echo FAIL
    exit 1
fi

echo ""
echo -n "Test skipping restricted for apparmor: "
out=$(SNAP=. ./bin/snappy-security-scanlog --only-apparmor -r --policy-version=16 --log-file=./test.log | grep -c 'kernel-module-control')
if [ "$out" = "0" ]; then
    echo PASS
else
    echo "Found $out entries"
    echo FAIL
    exit 1
fi

